#!/bin/sh

set -e

echo
echo "Running Python unit tests"
echo

python3 --version
echo

python3 python/test_mwmatching.py

echo
echo "Checking test coverage"
echo

coverage erase
coverage run --branch python/test_mwmatching.py
coverage report -m

echo
echo "Running Python code on test graphs"
echo

python3 python/run_matching.py --verify \
    tests/graphs/chain_n1000.edge \
    tests/graphs/chain_n5000.edge \
    tests/graphs/sparse_delta_n1004.edge \
    tests/graphs/triangles_n1002.edge \
    tests/graphs/triangles_n5001.edge \
    tests/graphs/random_n1000_m10000.edge \
    tests/graphs/random_n2000_m10000.edge

echo
echo "Running C++ unit tests"
echo

g++ --version
echo

make -C cpp run_matching test_mwmatching
cpp/test_mwmatching

echo
echo "Running C++ code on test graphs"
echo

python3 tests/run_test.py --solver cpp/run_matching --verify \
    tests/graphs/chain_n1000.edge \
    tests/graphs/chain_n5000.edge \
    tests/graphs/sparse_delta_n1004.edge \
    tests/graphs/triangles_n1002.edge \
    tests/graphs/triangles_n5001.edge \
    tests/graphs/random_n1000_m10000.edge \
    tests/graphs/random_n2000_m10000.edge

